Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Type ¶
type Type uint64
Type represents the type of the image detected, or `Unknown`.
const ( // Unknown represents an unknown image type Unknown Type = iota // BMP represendts a BMP image BMP // BPM represendts a BPM image BPM // GIF represendts a GIF image GIF // JPEG represendts a JPEG image JPEG // MNG represendts a MNG image MNG // PBM represendts a PBM image PBM // PCX represendts a PCX image PCX // PGM represendts a PGM image PGM // PNG represendts a PNG image PNG // PPM represendts a PPM image PPM // PSD represendts a PSD image PSD // RAS represendts a RAS image RAS // RGB represendts a RGB image RGB // TIFF represendts a TIFF image TIFF // WEBP represendts a WEBP image WEBP // XBM represendts a XBM image XBM // XPM represendts a XPM image XPM // XV represendts a XV image XV )
Click to show internal directories.
Click to hide internal directories.